@@ -1,7 +1,8 @@
+import sys
 import datetime
 import re
 from os import walk, mkdir
-from os.path import join, dirname, realpath, relpath
+from os.path import join, dirname, realpath, relpath, exists
 
 from jinja2 import Environment, FileSystemLoader
 
@@ -65,7 +66,11 @@ class StartApp(Plugin):
     def run(self, arguments, directory):
         current_dir = dirname(realpath(__file__))
         template_dir = join(current_dir, 'templates')
-        app_template_dir = join(template_dir, 'app')
+        
+        # choose the appropriate version for the app templates that is determined
+        # by the owncloud minimum version
+        app_dir = '%s/app' % arguments.owncloud.split('.')[0]
+        app_template_dir = join(template_dir, app_dir)
 
         # if author is given its being run from commandline and the list has to
         # be assembled first
@@ -104,6 +109,10 @@ class StartApp(Plugin):
 
         # create app directory
         app_dir = join(directory, params['app']['id'])
+        if exists(app_dir):
+            print('Can not create app, directory %s exists already' % app_dir)
+            sys.exit(1)
+
         mkdir(app_dir)
 
         # create folders and files in that directory
